Module blaxel.core.client.models.job_execution_task_spec
========================================================

Classes
-------

`JobExecutionTaskSpec(max_retries: blaxel.core.client.types.Unset | int = <blaxel.core.client.types.Unset object>, timeout: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>)`
:   Job execution task specification
    
    Attributes:
        max_retries (Union[Unset, int]): Maximum number of retries
        timeout (Union[Unset, str]): Task timeout duration
    
    Method generated by attrs for class JobExecutionTaskSpec.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    `max_retries: blaxel.core.client.types.Unset | int`
    :

    `timeout: blaxel.core.client.types.Unset | str`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :